// (C) Copyright 2011 Hewlett-Packard Development Company, L.P.
/**
 * @type (BaselineValidateView)
 * This is a view class for Validate Baseline menu option.
 */
define(['hpsum/presenter/baseline/BaselinePresenter',
	'hp/core/Router',
    'hp/core/Notifications',
	'hp/core/HelpMenu',
    'hp/core/Localizer',
    'hp/view/DialogView',
    'hp/view/FormStateView',
    'hp/model/Session',
    'text!hpsumpages/common/confirm_dialog.html',
    'jquery',
    'hp/lib/jquery.hpStackedPanels',
    'lib/jquery.selectBox',
    'lib/jquery.dataTables',
    'hp/lib/jquery.hpCollapsible',
    'hp/lib/jquery.hpToggle',
	'hp/lib/jquery.hpSearchCombo',
	'lib/jquery.jstree',
	'lib/jquery-ui-timepicker-addon'],
function(presenter, router, notifications, helpMenu, localizer, DialogView, FormStateView, session, dialogContent) { "use strict";

    var BaselineValidateView = (function() {
      
        var FORM = '#hpsum-baselines-validate-form',
        	SELECTED_BL = '#hpsum-validate-selected-baseline',
        	SELECTED_BL_XML = '#hpsum-vbl-xml',
			CANCEL = '#hpsum-validate-baselines-close',
			COMPONENTS_TABLE = '#baseline-validate-table',
            VALIDATION_TYPE = '#hpsum-validate-baseline-against',
            LOCATION_TYPE = '#hpsum-vbl-location-type',
            PROXY_OPTIONS = '#hpsum-vbl-proxy-options',
            CSM_VERSION = '#hpsum-csm-version',
            BROWSE_MATRIX_LOCATION_BUTTON = '#hpsum-vbl-browse-location',
            BROWSE_DIALOG = '#hpsum-browse-dialog',
            BROWSE_TREE = '#browse',
            MATRIX_PATH = '#hpsum-vbl-location-path',
            SPP_PATH = '#hpsum-vbl-spp-location-path',
            BROWSE_OK='#hp-baseline-add-ok',
            BROWSE_MATRIX_LOCATION_ERROR = '#hpsum-vbl-invalid-location-error',
            INFO_DIALOG = '#hpsum-info-dialog',
            MATRIX_LABEL = '#hpsum-vbl-location-label-path',
            VALIDATE  = '#hp-validate-baseline',
            TOTAL_SUMMARY = '#hpsum-vbl-total-summary',
            MISSING_SUMMARY = '#hpsum-vbl-missing-summary',
            SPLASH_DIALOG = '#hpsum-validate-wait-dialog',
            SPLASH_SPINNER = '#hpsum-validate-spinner',
            RETRIEVE_MATRIX_BUTTON = '#hpsum-baselines-getmatrix';
            
        /**
         * Constructor
         */
        function BaselineValidateView() {
            
            var oTableComponents;
            var proxyOptionValue;
            var browseDialogContents;
            var infoDialog;
            var baselineItem;
            var nodeTable = null;
            var formStateView = new FormStateView();
            var waitDialog;

            function onItemChange(item) {
            	baselineItem = item;
                if (item && item.hasOwnProperty("hapi")) {
                    $(SELECTED_BL).html(item.hapi.baseline_name + " " + item.hapi.baseline_version);
                    $(SELECTED_BL_XML).html(item.hapi.baseline_url + "/" + item.hapi.baseline_id + ".xml");
                }
            }

            function onValidate(){
                if($(VALIDATION_TYPE).val() === 'bundle'){
                    validateAgainstBundle();
                    $(VALIDATE).attr("disabled",true);
                }
                if($(VALIDATION_TYPE).val() === 'CSM'){
                    validateAgainstCSM();
                    $(VALIDATE).attr("disabled",true);
                }
            }

            function validateAgainstBundle(){
            	var msg = localizer.getString('hpsum.baseline.validate.validationInProgress');
            	showSaveWait(msg);
            	var URI;
            	URI = baselineItem.hapi.baseline_uri + "/validatebundleinventory";
            	presenter.startBundleValidation(URI,{
                        success : onValidationSuccess,
                        error : onValidationError
                    });
            }
            
            function onValidationSuccess(data){
            	closeSaveWait();
                var msg;
            	
            	if(data.hapi.hcode === 0)
            		msg = 'ok';
            	else{
                    msg = 'error';
                    if($(VALIDATION_TYPE).val() === 'bundle') {
                    	$('#hpsum-vbl-summary').show();                    	
                    }
                    if ($(VALIDATION_TYPE).val() === 'CSM') {
                    	$('#hpsum-vbl-summary').hide();
                    }
                    $('#hpsum-vbl-components').show();
                    $(MISSING_SUMMARY).html(data.hapi.total_no_of_component + localizer.getString('hpsum.baseline.validate.totalSummary') + ", " + data.hapi.total_no_of_missing_component + localizer.getString('hpsum.baseline.validate.missingSummary'));
                    //$(MISSING_SUMMARY).html(data.hapi.total_no_of_missing_component + localizer.getString('hpsum.baseline.validate.missingSummary'));
                    $(MISSING_SUMMARY).show();
                    $(MATRIX_LABEL).html(localizer.getString('hpsum.baseline.validate.csmPath'));
                    initComponentsTable();
                    populateComponentsTable(data);
                }
                     
               	formStateView.setMessage({
                    summary: data.hapi.hmessage,
                    status: msg,
                    details: ""});

                $(VALIDATE).attr("disabled", true);
            }
            
            function onValidationError(){
                closeSaveWait();
            	formStateView.setMessage({
                                summary: localizer.getString("hpsum.baseline.custom.validationErrorMsg"),
                                status: 'error',
                                details: ""});
            }

            function validateAgainstCSM(){
            	var msg = localizer.getString('hpsum.baseline.validate.validationInProgress');
            	showSaveWait(msg);
            	var URI;
            	URI = baselineItem.hapi.baseline_uri + "/validatereciepefile";
            	var selectedIndex = $('#hpsum-csm-version')[0].selectedIndex;
            	var selectedVersion = $('#hpsum-csm-version')[0][selectedIndex].text;             	
            	var input = {
            		hapi: {
            			csm_version : selectedVersion
            		}            		
            	};
            	presenter.validateReciepeFile(URI, input, {
                        success : onCSMValidationSuccess,
                        error : onCSMValidationError
                    });

            }

	    function onCSMValidationSuccess(data) {            	
            	closeSaveWait();
            	var msg;
            	
            	if(data.hapi.hcode === 0) {
            		msg = 'ok';            		
            	} else {
            		msg = 'error';
            		$('#hpsum-validate-csm-local').hide();
            	}
                
                $('#hpsum-vbl-summary').show();
                $('#hpsum-vbl-components').show();
                $(MISSING_SUMMARY).html(data.hapi.total_no_of_component + localizer.getString('hpsum.baseline.validate.totalSummary') + ", " + data.hapi.total_no_of_missing_component + localizer.getString('hpsum.baseline.validate.missingSummary'));
                //$(MISSING_SUMMARY).html(data.hapi.total_no_of_missing_component + localizer.getString('hpsum.baseline.validate.missingSummary'));
                $(MISSING_SUMMARY).show();
                $(MATRIX_LABEL).html(localizer.getString('hpsum.baseline.validate.csmPath'));
                initComponentsTable();
                populateComponentsTable(data);
               	formStateView.setMessage({
                    summary: data.hapi.hmessage,
                    status: msg,
                    details: ""});
            }
            
            function onCSMValidationError(data) {            	
            	closeSaveWait();
            }
			

            //Initialize install components table to add all the missing components
            function initComponentsTable() {
                
                  nodeTable = $(COMPONENTS_TABLE).dataTable({
                        oLanguage: {
                                sEmptyTable: localizer.getString('hpsum.node.noItemsFound')
                               },
                    sScrollY: "400px",
                    bScrollCollapse: true,
                    bPaginate : false,
                    bProcessing : true,
                    bFilter : true,
                    bSort : true,
                    bAutoWidth : true,
                    bInfo : false,
                    bRetrieve : true,
                    bDestroy : true,
                        aoColumns : [                            
                            {mDataProp: 'component_id'},
                            {mDataProp: 'package_name'},
                            {mDataProp: 'component_version'},
                            {mDataProp: 'found'}],
                    aaSorting: [],
                    });
                nodeTable.fnClearTable();
            }

            function populateComponentsTable(data){

                nodeTable = $(COMPONENTS_TABLE).dataTable();
                nodeTable.fnClearTable();
                nodeTable.fnAddData(data.hapi.missing_comp_list.component);
                nodeTable.fnAddData(data.hapi.available_components.component);
            }
            
            function setValidationType(){
                if($(VALIDATION_TYPE).val() == 'bundle'){
                    $('#hpsum-validate-csm-location-type').hide();
                    $('#hpsum-validate-csm-local').hide();
                    $('#hpsum-validate-csm-version').hide();
                    $('#hpsum-validate-csm-ftp').hide();
                    $('#hpsum-matrix-from-ftp').hide();
                    $(VALIDATE).attr("disabled", false);
                    $('#hpsum-vbl-summary').hide();
                    $('#hpsum-vbl-components').hide();
                    formStateView.reset();
                    $(RETRIEVE_MATRIX_BUTTON).hide();
                }
                else if($(VALIDATION_TYPE).val() == 'CSM'){
                    $('#hpsum-validate-csm-location-type').show();
                    //$('#hpsum-validate-csm-local').show();
                    $('#hpsum-validate-csm-local').hide();
                    $('#hpsum-validate-csm-version').hide();
                    $('#hpsum-matrix-from-ftp').show();
                    $('#hpsum-vbl-summary').hide();
                    $('#hpsum-vbl-components').hide();
                    $(LOCATION_TYPE).selectBox('value','local');
                    setLocationType();
                    formStateView.reset();
                }                 
            }

            function setLocationType(){
                if($(LOCATION_TYPE).val() == 'local'){
                    //$('#hpsum-validate-csm-local').show();
                    $('#hpsum-vbl-summary').hide();
                    $('#hpsum-vbl-components').hide();
                    $('#hpsum-validate-csm-local').hide();
                    $('#hpsum-validate-csm-version').hide();
                    $('#hpsum-validate-csm-ftp').hide();
                    $(PROXY_OPTIONS).hide();
                    $(MATRIX_PATH).val('');
                    $(MATRIX_LABEL).html(localizer.getString('hpsum.baseline.validate.csmPath'));
                    $(RETRIEVE_MATRIX_BUTTON).css( "display", "none" );
                    $(RETRIEVE_MATRIX_BUTTON).off('click',retrieveReciepeFile);
                    formStateView.reset();
                }
                else if($(LOCATION_TYPE).val() == 'FTP'){
                        $('#hpsum-validate-csm-local').hide();
                        $('#hpsum-validate-csm-version').hide();
                        $('#hpsum-validate-csm-ftp').show();
                        $('#hpsum-vbl-summary').hide();
                        $('#hpsum-vbl-components').hide();
                        $(MATRIX_PATH).val('');
                        $(MATRIX_LABEL).html(localizer.getString('hpsum.baseline.add.enterWorkingDirectory'));
                        $(RETRIEVE_MATRIX_BUTTON).show();
                        $(".hpsum-proxy").attr("disabled", false);
                        $('#hpsum-vbl-proxy-options').selectBox('enable');
                        $(PROXY_OPTIONS).selectBox('value', 'No');
                        onProxyOptionsChange('No');
                        $(RETRIEVE_MATRIX_BUTTON).on('click',retrieveReciepeFile);
                        
                        if($(MATRIX_PATH).val()== '')
                            $(RETRIEVE_MATRIX_BUTTON).attr("disabled", true);
                        
                        $(MATRIX_PATH).on('change',setRetrieveButtonState);
                        $(MATRIX_PATH).on('input',setRetrieveButtonState);
                        $(VALIDATE).attr("disabled", true);
                        formStateView.reset();
                    }             
            }

            function onProxyOptionsChange(msg) 
            {
                var value = $(PROXY_OPTIONS).val();
                if(value == "No" || msg == "No"){
                    $('#hpsum-vbl-proxy-usehp-item').hide();
                    $('#hpsum-vbl-proxy-usescript-item').hide();
                    proxyOptionValue = "No";
                }
                else if(value == "Server"){
                    $('#hpsum-vbl-proxy-usehp-item').show();
                    $('#hpsum-vbl-proxy-usescript-item').hide();
                    $('#hpsum-vbl-proxy-url').attr("disabled",false);
                    $('#hpsum-vbl-proxy-port').attr("disabled",false);
                    $('#hpsum-vbl-proxy-username').attr("disabled",false);
                    $('#hpsum-vbl-proxy-password').attr("disabled",false);
                    proxyOptionValue = "Server";
                }
                else if (value == "Script"){
                    $('#hpsum-vbl-proxy-usehp-item').hide();
                    $('#hpsum-vbl-proxy-usescript-item').show();
                    $('#hpsum-vbl-proxy-script').attr("disabled",false);
                    $('#hpsum-vbl-proxyscript-username').attr("disabled",false);
                    $('#hpsum-vbl-proxyscript-password').attr("disabled",false);
                    proxyOptionValue = "Script";
                }
            }

            /**
             * * Show information dialog to user such as selecting a valid baseline before proceed.
             */
            function showInfoDialog()
            {
                if (!infoDialog) {
                    infoDialog =  $(INFO_DIALOG);
                    infoDialog.dialog({
                        modal : true,
                        dialogClass: 'hp-simple-dialog',
                        position : "center",
                        draggable : false,
                        resizable : false
                    });
                    $('button', infoDialog).on('click', function () {
                        infoDialog.dialog('close');
                    });
                }
                infoDialog.dialog('open');
            }
            
            function showSaveWait(msg) {					
					
					if (!waitDialog) {
						waitDialog = $(SPLASH_DIALOG);
						waitDialog.dialog({
							modal : true,
							dialogClass : 'hp-simple-dialog',
							position : "center",
							draggable : false,
							resizable : false,
							width : 260,
							height : 180
						});
					}						                   

					$('#hpsum-bs-validate-wait-message', waitDialog).html(msg);
					$(SPLASH_SPINNER).show();
					msg='';
					waitDialog.dialog('open');
				}

				function closeSaveWait() {
					$(SPLASH_SPINNER).hide();
					if (waitDialog) {
						waitDialog.dialog('close');
					}
				}
            
            /**
             * * Saves the given local matrix xml file and wait for the engine to response
             * * Till engine response page will be blocked. 
             */
            function saveLocalMatrixFile(matrixXmlFile) {
            	var msg = localizer.getString('hpsum.baseline.validate.saveInProgress');
            	showSaveWait(msg);
            	            	
            	var input = {
            		hapi: {
            			uri : matrixXmlFile            			
            		}            		
            	};
            	
            	presenter.saveReciepeFile(input, 
            		{
                        success : onItemSaveSuccess,
                        error : onItemSaveError
                    });            	
            }
            
            
            function onItemSaveSuccess(data) {
            	
            	closeSaveWait();
            	var msg;
            	
            	if(data.hapi.hcode === 0) {
            		msg = 'success';
            		$('#hpsum-validate-csm-local').show();
                    $('#hpsum-validate-csm-version').show();
            		var versions = data.hapi.available_versions.matrix_version;
            		var length = versions.length;
            		var selectdata = '<select id=hpsum-csm-version class= hp-select>';
            		for(var i = 0; i < length; ++i) {
            			var ver = versions[i].version;
            			var baseline = versions[i].associated_bundle_name;
            			selectdata += '<option value="' + baseline + '">' + ver + '</option>';
            		}
            		selectdata += '</select>';
            		$('#hpsum-csm-selectbox').html(selectdata);
            		var selectvalue = $('#hpsum-csm-version').val();
            		$('#hpsum-starting-bl-used-value').text(selectvalue);	
            		$('#hpsum-csm-version').change(function(){
            			var selectvalue = $('#hpsum-csm-version').val();
            			$('#hpsum-starting-bl-used-value').text(selectvalue);
                        $(VALIDATE).attr("disabled", false);
                        if(nodeTable != null)
                            nodeTable.fnClearTable();
                        formStateView.reset();
                        $(MISSING_SUMMARY).hide();
            		});
            	} else {
            		msg = 'error';
            		$('#hpsum-validate-csm-local').hide();
                    $('#hpsum-validate-csm-version').hide();
            	}
                     
               	formStateView.setMessage({
                    summary: data.hapi.hmessage,
                    status: msg,
                    details: ""});
            	
            }
            
            function onItemSaveError(data) {
            	closeSaveWait();
            }
            
            function getProxyJsonObject(){
                var proxy_settings;
                if((proxyOptionValue == "No") || (proxyOptionValue == undefined))
                    proxy_settings ='';
                else if(proxyOptionValue == "Server"){
                    proxy_settings = {
                        proxy_username: $('#hpsum-vbl-proxy-username').val(),
                        proxy_password: $('#hpsum-vbl-proxy-password').val(),
                        proxy_ftp_port: $('#hpsum-vbl-proxy-port').val(),
                        proxy_url: $('#hpsum-vbl-proxy-url').val(),
                        use_proxy_script:false
                    };
                }
                else if(proxyOptionValue == "Script"){
                    proxy_settings = {
                        proxy_username: $('#hpsum-vbl-proxyscript-username').val(),
                        proxy_password: $('#hpsum-vbl-proxyscript-password').val(),
                        use_proxy_script: true,
                        proxy_script: $('#hpsum-vbl-proxy-script').val()
                    };
                }
                return proxy_settings;
            }

            function retrieveReciepeFile() {
                var input = {
                    hapi: {
                        working_location :$(MATRIX_PATH).val(),
                        proxy_settings: getProxyJsonObject()
                    }
                };
                
                presenter.getPFWReciepefile(input, {
                    success:function(data){
                        closeSaveWait();
                        $(".hpsum-proxy").attr("disabled", true);
                        $('#hpsum-proxy-options').selectBox('disable');

                        var msg;
                        
                        if(data.hapi.hcode === 0) {
                            msg = 'ok';
                            var xmlFile = $(MATRIX_PATH).val() + "/MatrixConfig.xml";
                            saveLocalMatrixFile(xmlFile);
                            $(VALIDATE).attr("disabled", false);
                        }
                        else{
                            msg = 'error';
                        }
                             
                        formStateView.setMessage({
                            summary: data.hapi.hmessage,
                            status: msg,
                            details: ""});
                    },
                    error:function(message) {
                        closeSaveWait();
                    }
                });

                showSaveWait(localizer.getString('hpsum.baseline.validate.retrieveInProgress'));
            }

            function setRetrieveButtonState(){
                if($(LOCATION_TYPE).val() == 'FTP'){
                       if($(MATRIX_PATH).val()== '')
                            $(RETRIEVE_MATRIX_BUTTON).attr("disabled", true);
                        else
                            $(RETRIEVE_MATRIX_BUTTON).attr("disabled", false);
                      }
            }

            /**
             * * Initialize and display browse dialog.
             * * User can navigate to any folder and choose a valid matrix file location 
             */
            function initBrowseMatrixDialog(){
                var dialogView = new DialogView();
                dialogView.init({contents: browseDialogContents,
                    position : "center",
                    ok: function (elem) {
                        
                        var node = $(BROWSE_TREE).jstree('get_selected');
                        if(node[0] == null)//|| (node[0] && node[0].attributes["rel"].value != "package"))
                        {
                            var loc_type = $(LOCATION_TYPE).val();
                            if(loc_type == 'local')
                            {
                                showInfoDialog();
                                return false;
                            }
                        }
                        //$(MATRIX_PATH).val(node[0].id);
                        //$(MATRIX_PATH).trigger('change');
                        if($(LOCATION_TYPE).val() == 'local') {
                            $(VALIDATE).attr("disabled", false);
                            $('#hpsum-validate-csm-version').show();
                            $('#hpsum-validate-csm-local').show();
                            var xmlFile = $(MATRIX_PATH).val();
                       		saveLocalMatrixFile(xmlFile);
                       	} else {
                       		$(MATRIX_PATH).val(node[0].id);
                        	$(MATRIX_PATH).trigger('change'); 
                        }
                    },
                    cancel: function () {
                        $(MATRIX_PATH).val('');
                        $(MATRIX_PATH).trigger('change');
                    }
                });
            }

            function onPathEdit() {
                $(BROWSE_MATRIX_LOCATION_ERROR).hide();
                $(MATRIX_PATH).removeClass("hp-error");
                $(MATRIX_PATH).unbind('keyup', onPathEdit);
            }

            function handleInvalidPath(hapi) {
                if (hapi.hcode == 5) {
                    $(BROWSE_MATRIX_LOCATION_ERROR).text(localizer.getString('hpsum.baseline.add.inValidLocation'));
                    $(MATRIX_PATH).addClass("hp-error");
                    $(BROWSE_MATRIX_LOCATION_ERROR).show();
                    $(MATRIX_PATH).keyup(onPathEdit);
                    $('#browse-dialog-cancel').trigger('click');
                        $(VALIDATE).attr("disabled", true);
                } else {
                    $(BROWSE_MATRIX_LOCATION_ERROR).hide();
                    $(MATRIX_PATH).removeClass("hp-error");
                    $(MATRIX_PATH).unbind('keyup', onPathEdit);
                }
            }

            /**
             * * Create a JsTree inside the browse dialog.
             * * This includes operations such as JSON data load through AJAX call, configuration of tree etc.
             */
            function createTree(){
                
                var uri = "Session/" + session.getToken()  + "/Baseline/browse";
                var initial_folder = $(MATRIX_PATH).val();
                
                $(BROWSE_TREE).empty();
                $(BROWSE_TREE).jstree({
                        "json_data" : {
                                   "ajax" : {
                                        "url" : function (node) {
                                            var url;
                                            if (node == -1) {
                                                url = "Session/" + session.getToken()  + "/Baseline/browse";
                                            } else {
                                                url = null;
                                            }
                                            return url;
                                        },
                                        "type" : "POST",
                                        "dataType" : "json",
                                        "data" : function (n) { 
                                                var object = {
                                                        "hapi": {
                                                            "uri": $(MATRIX_PATH).val().length > 0 ? $(MATRIX_PATH).val() : "..",
                                                            "showXml": true
                                                        }
                                                    }; 
                                                
                                                return JSON.stringify(object); 
                                        },
                                        "success" : function (output) {
                                            
                                            var data = [], children = [], index, node, bAddParent = false;
                                            
                                            //This will handle if user has given an invalid location to browse.
                                            handleInvalidPath(output.hapi);
                                            
                                            //hcode has string value in the response payload. This need to be changed later when it is 
                                            //changed to integer value
                                            if(output.hapi.hcode != "0")
                                            {
                                                //add a node to navigate to parent directory 
                                                node = {
                                                            "data" : "..",
                                                            "attr" : { "id" : "..", "rel" : "parent"},
                                                            "state" : "open",
                                                           }
                                                           
                                                data.push( node );
                                                return data;
                                            }
                                            
                                            //iterate through folders and create child nodes
                                            for(var i=0; i < output.hapi.folders.folder.length; i++ ){
                                                var folder = output.hapi.folders.folder[i];
                                                var child, rel;
                                                
                                                if(i === 0) 
                                                {
                                                    var str = $(MATRIX_PATH).val();
                                                    if(str === '/')
                                                    {
                                                        bAddParent = false;
                                                    }
                                                    else if(i == 0) // && (str.length > 0 && str.indexOf('/') === -1)) 
                                                    {
                                                        bAddParent = true;
                                                        continue;
                                                    }
                                                }   
                                                
                                                //if it is root folder and drive, add the first item as a sibling node instead of parent node
                                                //change icon if folder is a valid package
                                                if(folder.possible_package)
                                                    rel = "package";
                                                else
                                                    rel = "folder";
                                                
                                                //take only last folder name from complete path
                                                //var str = folder.folder_name.substring(folder.folder_name.lastIndexOf('/')+1);
                                                var strfolder, idfolder;
                                                if(str === '/' && folder.folder_name.indexOf('/') != 0) {
                                                    strfolder = folder.folder_name.substring(0, folder.folder_name.indexOf('/')-1);
                                                    idfolder = folder.folder_name.substring(0, folder.folder_name.indexOf('/'));
                                                }
                                                else {
                                                strfolder = folder.folder_name.substring(folder.folder_name.lastIndexOf('/')+1);
                                                idfolder = folder.folder_name;
                                                }
                                                
                                                //create children nodes
                                                if(strfolder.length > 0 && idfolder.length > 0) {
                                                    child = {
                                                        "data" : strfolder,
                                                         "attr" : {"id" : idfolder, "rel" : rel}
                                                        }
                                                    children.push( child );
                                                }
                                            }
                                            
                                            //add a node to navigate to parent directory 
                                            node = {
                                                        "data" : "..",
                                                        "attr" : { "id" : "..", "rel" : "parent"},
                                                        "state" : "open",
                                                       }
                                                       
                                            data.push( node );
                                            
                                            if(bAddParent) {
                                                var rel, val;
                                                if(output.hapi.folders.folder[0].possible_package)
                                                    rel = "package";
                                                else
                                                    rel = "folder";
                                                    
                                                if($(MATRIX_PATH).val() === '')
                                                    val = output.hapi.folders.folder[0].folder_name
                                                else
                                                    val = $(MATRIX_PATH).val();
                                                //add parent folder to folder list
                                                node = {
                                                            "data" : val,//output.hapi.folders.folder[0].folder_name,
                                                            "attr" : { "id" : val, "rel" : rel}, //{ "id" : output.hapi.folders.folder[0].folder_name, "rel" : rel},
                                                            "metadata" :  output.hapi.folders.folder[0],
                                                            "state" : "open",
                                                            "children" : children
                                                           }
                                                           
                                                data.push( node );
                                            }
                                            else
                                            {
                                                data.push(children);
                                            }
                                            
                                                        
                                            return data;
                                        }
                                   }
                        },
                        "themes" : {
                                "theme" : "default",
                                "url" : "/css/style.css",
                                "dots" : true,
                                "icons" : true
                        },
                        "plugins" : [ "themes", "json_data", "ui" , "crrm", "types" ],
                        "types" : {
                                "max_depth" : -2,
                                "max_children" : -2,
                                "valid_children" : [ "drive" ],
                                "types" : {
                                        "default" : {
                                                "valid_children" : "none",
                                                "icon" : {
                                                        "image" : "/img/hp-piano/collapse-closed.png"
                                                }
                                        },
                                        "folder" : {
                                                "valid_children" : [ "default", "folder", "package" ],
                                                "icon" : {
                                                        "image" : "/img/hp-piano/collapse-closed.png"
                                                }
                                        },
                                        "package" : {
                                                "valid_children" : [ "default", "folder" ],
                                                "icon" : {
                                                        "image" : "/img/hp-piano/status-ok.png"
                                                }
                                        },
                                        "drive" : {
                                                "valid_children" : [ "default", "folder" ],
                                                "icon" : {
                                                        "image" : "/img/hp-piano/down-arrow.png"
                                                },
                                                "start_drag" : false,
                                                "move_node" : false,
                                                "delete_node" : false,
                                                "remove" : false
                                        },
                                        "parent" : {
                                                "valid_children" : [ "default", "folder", "drive", "package" ],
                                                "icon" : {
                                                        "image" : "/img/hp-piano/grid-collapse.png"
                                                },
                                                "start_drag" : false,
                                                "move_node" : false,
                                                "delete_node" : false,
                                                "remove" : false
                                        }
                                        
                                }
                        }
                })
                .bind("dblclick.jstree", function (event, data) {
                        var node = $(BROWSE_TREE).jstree('get_selected');
                        var xmlname = node[0].id;
                		if (xmlname.match(".xml$"))
                			return;
                        if(node[0].id === "..")
                        {
                            if(node[0].nextSibling)
                            {
                                var str = $(MATRIX_PATH).val(); 
                                if(str === '')
                                {
                                    $(MATRIX_PATH).val(node[0].nextSibling.id.substring(0, node[0].nextSibling.id.lastIndexOf("/")));
                                    $(MATRIX_PATH).trigger('change');
                                }
                                else if(str === '/')
                                {
                                    
                                }
                                else
                                {
                                    if(str.indexOf('/') != -1){
                                        $(MATRIX_PATH).val(node[0].nextSibling.id.substring(0, node[0].nextSibling.id.lastIndexOf("/")));
                                        $(MATRIX_PATH).trigger('change');
                                    }
                                    else{
                                        $(MATRIX_PATH).val("/");
                                        $(MATRIX_PATH).trigger('change');
                                    }
                                }
                            }
                            else
                            {
                                $(MATRIX_PATH).val("/");
                                $(MATRIX_PATH).trigger('change');
                            }
                        }
                        else 
                        {   
                            $(MATRIX_PATH).val(node[0].id);
                            $(MATRIX_PATH).trigger('change');
                        }
                        
                        $(BROWSE_TREE).jstree("refresh");
                })
                .bind("select_node.jstree", function (event, data) { 
                    var node = $(BROWSE_TREE).jstree('get_selected');
                    var str = $(MATRIX_PATH).val(); 
                    var xmlname = node[0].id;
                    
                    var loc_type = $(LOCATION_TYPE).val();
                    if (loc_type != 'FTP'){
                        /*if(node[0] )&& node[0].attributes["rel"].value != "package")
                            $(BROWSE_OK).attr("disabled","disabled");
                        else*/
                            if (xmlname.match(".xml$") && !(str.match(".xml$"))) {
                    			var xmlFileSelected=str + "/" + xmlname;                    			
                    			$(MATRIX_PATH).val(xmlFileSelected);
                    			$(MATRIX_PATH).trigger('change');
								$(BROWSE_OK).removeAttr("disabled");								
                    		}
                    }                    
                    else
                        $(BROWSE_OK).removeAttr("disabled");
                        });
                }

            function reset() {
                setValidationType();
                //'#hpsum-validate-csm-location-type').hide();
                //'#hpsum-validate-csm-ftp').hide();
                //'#hpsum-validate-csm-local').hide();
                $('#hpsum-vbl-proxy-usehp-item').hide();
                $('#hpsum-vbl-proxy-usescript-item').hide();
                $('#hpsum-vbl-summary').hide();
                $('#hpsum-vbl-components').hide();
                $('#PROXY_OPTIONS').selectBox('value', 'No');
               //('#hpsum-matrix-from-ftp').hide();
                $(MATRIX_PATH).val("");
                $(SELECTED_BL).html("");
                $(SELECTED_BL_XML).html("");
                $(VALIDATE).attr("disabled", false);
                $(PROXY_OPTIONS).hide();
                formStateView.reset();
            }
            
          	/**
             * @public
             */
            this.resume = function () {
                $(VALIDATION_TYPE).selectBox('value','bundle');
                $(LOCATION_TYPE).selectBox('value','local');
                setLocationType();
                $(PROXY_OPTIONS).selectBox('value', "No");                
                $(RETRIEVE_MATRIX_BUTTON).attr("disabled", false);
                $(RETRIEVE_MATRIX_BUTTON).css( "display", "none" );
                $(MATRIX_PATH).attr("disabled", false);
                reset();
                presenter.on("itemChange", onItemChange);
            };
            
            this.pause = function () {
                presenter.off("itemChange", onItemChange);
            };
            
            /**
             * @public
             * Initialization funtion for the object
             * All the controls actions are initialized in this function.
             */
            this.init = function() {
                $('#hpsum-vbl-title').text(localizer.getString("hpsum.baseline.validate.csmTitle"));
                $(VALIDATION_TYPE).selectBox({autoWidth: false});
                $(LOCATION_TYPE).selectBox({autoWidth: false});
                $(PROXY_OPTIONS).selectBox({autoWidth: false});
                $(CSM_VERSION).selectBox({autoWidth: false});
                $(VALIDATION_TYPE).change(setValidationType);
                $(LOCATION_TYPE).change(setLocationType);
                $(PROXY_OPTIONS).change(onProxyOptionsChange);
                $(VALIDATE).attr("disabled", false);
                $(RETRIEVE_MATRIX_BUTTON).css( "display", "none" );
		$('#hpsum-validate-baseline-matrixhelp').attr('tooltip', localizer.getString('hpsum.baseline.validate.locationTypehelp')).hpTooltip();
		$('#hpsum-validate-baseline-typehelp').attr('tooltip', localizer.getString('hpsum.baseline.validate.validationTypehelp')).hpTooltip();
		$('#hpsum-validate-baseline-proxyhelp').attr('tooltip', localizer.getString('hpsum.baseline.add.proxyOptionshelp')).hpTooltip();
                browseDialogContents = $(BROWSE_DIALOG).detach().show();

                $(BROWSE_MATRIX_LOCATION_BUTTON).on('click', function() {
                    initBrowseMatrixDialog();
                    $(BROWSE_OK).attr("disabled", "disabled");
                    createTree();
                });

                $(VALIDATE).on('click',function(){
                    onValidate();
                });

                formStateView.reset();
                formStateView.init({form: FORM, routePattern: "" + '.*', autoTrack: true});

                this.resume();
            };
        }

        return BaselineValidateView;
    }());
    
    return new BaselineValidateView();
});