// (C) Copyright 2013 Hewlett-Packard Development Company, L.P.
/**
 * @type (GroupDeployView)
 * This is a view class for Group Deploy View.
 */
define(['hpsum/presenter/group/GroupPresenter',
    'hpsum/presenter/node/NodePresenter',
	'hp/core/Router',
	'hp/core/UrlFragment',
    'hp/core/Notifications',
	'hp/core/HelpMenu',
	'hp/view/DialogView',
	'hp/core/Localizer',
    'jquery',
    'hpsum/view/node/jquery.hpsumInstallables',	
    'hp/lib/jquery.hpStackedPanels',
    'lib/jquery.selectBox',
    'lib/jquery.dataTables',
    'lib/jquery.dataTables.rowReordering',
    'hp/lib/jquery.hpCollapsible',
    'hp/lib/jquery.hpToggle',	
	'hp/lib/jquery.hpSearchCombo'
	],

function(presenter, nodePresenter, router, urlFragment, notifications, helpMenu, DialogView, localizer) {"use strict";

	var GroupDeployView = ( function() {

			//Consts can go here
			var DEPLOY = '#hpsum-group-deploy-ok',
			    ANALYSIS = '#hpsum-group-analysis',
			    RESET = '#hpsum-group-reset',
			    CANCEL = '#hpsum-group-deploy-close',
			    DEPLOY_CONTENTS = '#hpsum-group-deploy',
			    GROUP_NODE_DEPLOY_CONTENT = '#hpsum-group-node-deploy-data',
			    PANEL_SELECTOR = '#hpsum-deploy-panel-selector',
			    FIRST_ANCHOR = PANEL_SELECTOR + ' a[href]:first',
			    PANELS = '#hpsum-group-deploy-panels',
			    NAME = '#hpsum-group-deploy-name',
			    REBOOTOPTION = '#hpsum-deploy-reboot-option',
				INSTALLATIONOPTION = '#hpsum-installation-option',
			    DELAYSEC = '#hpsum-group-deploy-delay-seconds',
				DELAYSECERR = '#hpsum-group-deploy-delay-seconds-err',
			    MESSAGE = '#hpsum-group-deploy-reboot-message',
			    ROUTE_PREFIX = '/group/deploy',
			    NONECHECKBOX = '.nonecheckbox',
			    USESNMPCHECKBOX = '.useSNMPcheckbox',
			    USEAGENTLESSCHECKBOX = '.useAgentlesscheckbox',
			    USEWEBEMCHECKBOX = '.useWEBEMcheckbox',
			    DOWNGRADECHKBOXCOMP = '.downgradechkbox',
			    REWRITECHKBOXCOMP = '.rewritechkbox',
			    FIRMWARECHKBOXCOMP = '.firmwarechkbox',
			    SOFTWARECHKBOXCOMP = '.softwarechkbox',
			    SPLASH_DIALOG = '#hpsum-group-analysis-dialog',
			    SPLASH_SPINNER = '#hpsum-group-analysis-spinner',
			    THROBBER = '#hpsum-group-deploy-throbber',
				SCHEDULETOGGLE = '#hpsum-group-schedule-enable',
				DATETIMESECTION = '#hpsum-group-schedule-datetimepick',
				SCHEDULE_DATE = '#hpsum-group-schedule-date',
				SCHEDULE_TIME = '#hpsum-group-schedule-time',
				SCHEDULE_TIME_LABEL = '#hpsum-node-schedule-time-label',
				SCHEDULE_WARNING = '#hpsum-group-schedule-warning',
				SCHEDULE_LIST = '#hpsum-group-node-list',
				CURRENT_DATETIME = '#hpsum-group-current-datetime',
				INSTALL_ERROR='#force-options-tbody-err',
				TIME_ZONE = '#hpsum-group-timezone',
				REBOOT_DISABLE = '.hpsum-otu-group-deploy-disable';
				

			/**
			 * Constructor
			 */
			function GroupDeployView() {

				var groupItem = null,
				setAttributesOnGroup = false,
				analysisWaitDialog = null, 
				defaultOptiondetails = {
					hapi : {
						installation_option : {
							downgrade : false,
							rewrite : false,
							force : false,
							firmware:false,
							software:false
						},

						reboot_options : {
							action : 'Never',
							delay : '3600',
							message : 'Reboot at user request after deploy'
						}
					}
				},
				optiondetails = defaultOptiondetails,
				nodeChanges = [],
				nodeTPMMap = [],
				analysisNeededNodes = 0,
				initialGetattr = null;
			var scheduled_getdata_date_time = '',
				scheduled_getdata = '',
				schedaction = '',
				schedule_time = '',
				date_time_new = '',
				time_value = '',
				date_value = '',
				allNodesDetials = [],
				warningmsg = '';

				function onItemChange(item) {
					groupItem = item.hapi;

					if (groupItem) {
						$(NAME).text(groupItem.group_name);
						$(ANALYSIS).attr("disabled", true);
						$(DEPLOY).attr("disabled", false);
						presenter.getAttributes(groupItem, {
							success : function(data) {
								if(data.hapi.hcode == 0)
									showoptions(data);
							},
							error : function(data) {
							}
						});
						presenter.getNodesData(groupItem, {
							success : function(data) {
								allNodesDetials = [];
								if (data.hasOwnProperty('hapi')) {
									allNodesDetials = data.hapi.output_data.nodes.node;
									loadScheduleoptions(groupItem);
								}
							},
							error : function(data) {
							}
						});
						populateDeployData();
					} else {
						$(CANCEL).trigger('click');
					}
				}

				function setoptiondetails() {
					var optionSelected = false,
					    atleastOneOptionSelected = false;
					
					optiondetails.hapi.installation_option.force = false;
					optiondetails.hapi.installation_option.downgrade = false;
					optiondetails.hapi.installation_option.rewrite = false;
					var type = $(INSTALLATIONOPTION).val();
					if ( type=="Downgrade") 
						optiondetails.hapi.installation_option.downgrade = true;
					if ( type=="Rewrite") 
						optiondetails.hapi.installation_option.rewrite = true;
					if ( type == "Both")
					{
						optiondetails.hapi.installation_option.downgrade = true;
						optiondetails.hapi.installation_option.rewrite = true;
					}
						
					optiondetails.hapi.installation_option.software =  $(SOFTWARECHKBOXCOMP).is(':checked');	
					optiondetails.hapi.installation_option.firmware =  $(FIRMWARECHKBOXCOMP).is(':checked');	
					if ( optiondetails.hapi.installation_option.software || optiondetails.hapi.installation_option.firmware )
						optiondetails.hapi.installation_option.force = true;
					
					if (($(REBOOTOPTION).val() == "If needed") || ($(REBOOTOPTION).val() == "Always")) {
						atleastOneOptionSelected = true;
					}
					optiondetails.hapi.reboot_options.action = $(REBOOTOPTION).val();
					
					if (($(DELAYSEC).val() != '') && ($(DELAYSEC).val().match(/^[0-9]+$/) !== null)) {
						optiondetails.hapi.reboot_options.delay = $(DELAYSEC).val();
					}
					
					if ($(MESSAGE).val() != '') {
						optiondetails.hapi.reboot_options.message = $(MESSAGE).val();
					}
					
					if(initialGetattr.installation_option.downgrade != optiondetails.hapi.installation_option.downgrade ||
					initialGetattr.installation_option.rewrite != optiondetails.hapi.installation_option.rewrite ||
					initialGetattr.installation_option.software != optiondetails.hapi.installation_option.software ||
					initialGetattr.installation_option.firmware != optiondetails.hapi.installation_option.firmware ||
					initialGetattr.reboot_options.action != optiondetails.hapi.reboot_options.action ||
					initialGetattr.reboot_options.delay != optiondetails.hapi.reboot_options.delay ||
					initialGetattr.reboot_options.message != optiondetails.hapi.reboot_options.message) {
						atleastOneOptionSelected = true;
					}
					else
						atleastOneOptionSelected = false;
					
					if (!atleastOneOptionSelected) {
						optiondetails.hapi.installation_option = {};
						optiondetails.hapi.reboot_options = {};
					} else {
						setAttributesOnGroup = true;
					}
					atleastOneOptionSelected = false;
				}
				
				function showoptions(data)
				{
					initialGetattr = null;
					if(data && data.hasOwnProperty("hapi"))
					{
						initialGetattr = data.hapi;
						if(data.hapi.hasOwnProperty("reboot_options") && data.hapi.reboot_options)
						{
							$('#hpsum-deploy-reboot-option option').filter(function() {
							if(new RegExp(this.value, 'ig').test( data.hapi.reboot_options.action))
		    		            $(this).attr('selected', true);
							});
							if( -1 < data.hapi.reboot_options.delay){
								$(DELAYSEC).val(data.hapi.reboot_options.delay);				
							}
							else{
								$(DELAYSEC).val('3600');				
							}
						
							$(MESSAGE).attr('value', data.hapi.reboot_options.message);
							$(REBOOTOPTION).selectBox('reset');
						}
					
						if(data.hapi.hasOwnProperty("installation_option") && data.hapi.installation_option)
						{
							if ( !data.hapi.installation_option.rewrite  && !data.hapi.installation_option.downgrade )
							{
								$(INSTALLATIONOPTION).val('None');
								$('#hp-force-downgrade-rewrite').hide();
							}
							else if ( data.hapi.installation_option.rewrite  && data.hapi.installation_option.downgrade )
							{
								$(INSTALLATIONOPTION).val('Both');
								$('#hp-force-downgrade-rewrite').show();
							}
							else 
							{
								if (data.hapi.installation_option.rewrite )
									$(INSTALLATIONOPTION).val('Rewrite');
						
								if (data.hapi.installation_option.downgrade )
									$(INSTALLATIONOPTION).val('Downgrade');
								$('#hp-force-downgrade-rewrite').show();
							}
											
							$(INSTALLATIONOPTION).selectBox('reset');
							$(FIRMWARECHKBOXCOMP).attr('checked', data.hapi.installation_option.firmware);							
							$(SOFTWARECHKBOXCOMP).attr('checked', data.hapi.installation_option.software);					
											
						}
					}
				}
			
			function validate()
			{
				var type = $(INSTALLATIONOPTION).val();
				var software = $(FIRMWARECHKBOXCOMP).is(':checked');
				var firmware = $(SOFTWARECHKBOXCOMP).is(':checked');
				if ( type !='None' )
				{
					if ( !(software || firmware ))
					return false;
				
				}
				return true;
			}
			function errormsg()
			{
				$(INSTALL_ERROR).hide();
			}

				function onSetattributeSuccess(item) {
					performAnalysis();
					setAttributesOnGroup = false;
				}

				function onSetattributeError(errorMessage) {
					notifications.show(errorMessage, 'error');
					$(DEPLOY).attr("disabled", true);
					$(CANCEL).trigger('click');
					setAttributesOnGroup = false;
				}

				function onDeploy() {				
					$(DEPLOY).attr('disabled', true);
					$(THROBBER).show();
					for (var idx = 0; idx < nodeChanges.length; idx++) {
						if (nodeTPMMap[nodeChanges[idx].node_id] == true) {
							nodePresenter.setattribute({
								node_id: nodeChanges[idx].node_id
							},{
								hapi : {
									tpm_bypass : 'true',
									node_id : nodeChanges[idx].node_id
								}
							}, {
								success : function(data) {
									if (data.hapi.hcode == 0) {
										
									} else {
										notifications.show(data.hapi.hmessage);
										$(CANCEL).trigger('click');
									}
								},
								error : function(data) {
								}
							});
						}
					}
										
					presenter.deploy(groupItem, {
						success : onDeploySuccess,
						error : onDeployError
					});
				}


				function onDeploySuccess(item) {
					$(THROBBER).hide();
					notifications.show(groupItem.group_name + ' Group ' + localizer.getString("hpsum.group.deployStarted"), 'ok');
					$(CANCEL).trigger('click');
				}

				function onDeployError(errorMessage) {
					$(THROBBER).hide();
					notifications.show(errorMessage, 'error');
					$(CANCEL).trigger('click');
				}

				function changeLocation(location) {
					if (location.length > ROUTE_PREFIX.length) {
						$(PANELS).hpStackedPanels('setPanelByLocation', '#' + location);
					} else {
						$(PANELS).hpStackedPanels('setFirstPanel');
					}
				}

				function populateOptions() {
					optiondetails = defaultOptiondetails;
					$(NONECHECKBOX).attr('checked', false);
					$(USESNMPCHECKBOX).attr('checked', false);
					$(USEAGENTLESSCHECKBOX).attr('checked', false);
					$(USEWEBEMCHECKBOX).attr('checked', false);
					
					
					$(INSTALLATIONOPTION).val('None');
					$(INSTALLATIONOPTION).selectBox('reset');
					$('#hp-force-downgrade-rewrite').hide();

					$(FIRMWARECHKBOXCOMP).attr('checked', false);
					$(SOFTWARECHKBOXCOMP).attr('checked', false);

					$(REBOOTOPTION).selectBox('value', 'Never');
					$(INSTALL_ERROR).hide();
					$(DELAYSEC).val('3600');
					$('textarea' + MESSAGE).attr('value', 'Reboot at user request after deploy');
				}

				function populateDeployData() {
					var groupNodes = [],
					    groupNodeData,
					    id,
					    contentid,
					    name,
					    htmlContents = '';
					nodeChanges = [];
					if(groupItem)
						groupNodes = groupItem.group_nodes.group_node;
					else
						return;
					for (var idx = 0; idx < groupNodes.length; idx++) {
						id = 'hpsum-group-node-collapse-' + groupNodes[idx];
						contentid = 'hpsum-group-node-ccontent-' + groupNodes[idx];
						name  = 'hpsum-group-node-cname-' + groupNodes[idx];
						htmlContents += '<div class ="my-collapsible" id ="' + id +
						'" data="' + groupNodes[idx] + '"><label id ="'+ name +'" style="clear: both">' + groupNodes[idx] + '</label>' +
						'<div class="hp-notify hp-notify-warning hp-hide" style="" id="hpsum-group-tpm-warning-' + groupNodes[idx] + '">"' +
						localizer.getString("hpsum.oneTouchUpdate.tpmWarning") + '</div>' +
						'<div id ="' + contentid + '"><label>Collapse Content</label></div></div>';
						
						nodePresenter.getNodeData({node_id: groupNodes[idx]}, {
							success: function(data) {
								$('#hpsum-group-node-cname-' + data.hapi.node_id).html(data.hapi.name);
								nodeChanges = nodeChanges.concat({
									node_id: data.hapi.node_id,
									selectionChanged: false,
									node_name: data.hapi.name,
									component_length : 0,
									failed_dependency_cnt : 0,
									is_schedule_running : data.hapi.is_schedule_running,
									scheduled : data.hapi.scheduled,
									schedule_date_time : data.hapi.schedule_date_time
									});
								if (data.hapi.tpm_state == true) {
									$('#hpsum-group-tpm-warning-' + data.hapi.node_id, DEPLOY_CONTENTS).show();
								}
								nodeTPMMap[data.hapi.node_id] = data.hapi.tpm_state;
							},
							error: function() {
							}
						});
					}
					
					$(GROUP_NODE_DEPLOY_CONTENT, DEPLOY_CONTENTS).html(htmlContents);
					$('.my-collapsible', DEPLOY_CONTENTS).hpCollapsible();
					
					for (var idx = 0; idx < groupNodes.length; idx++) {
						$('#hpsum-group-node-ccontent-' + groupNodes[idx], DEPLOY_CONTENTS).hpsumInstallables({
								command: 'init',
								nodeItem: {node_id: groupNodes[idx], type: ''},
								onSelectionChanged: onSelectionChanged
							});
						$('#hpsum-group-tpm-warning-' + groupNodes[idx], DEPLOY_CONTENTS).hide();	
					}
					
				}
				
				function onSelectionChanged(id, value, componentList) {		
					if (value == true) {
						$(DEPLOY).attr("disabled", true);
						$(ANALYSIS).attr("disabled", false);
					} else {
						  if (componentList.failed_dependency > 0) {
							$(DEPLOY).attr("disabled", true);
							$(ANALYSIS).attr("disabled", true);
						}
					}
					
					var nodeName = '';
					for (var idx = 0; idx < nodeChanges.length; idx++) {
						if (nodeChanges[idx].node_id == id){
							nodeChanges[idx].selectionChanged = value;
							nodeName = nodeChanges[idx].node_name;
							nodeChanges[idx].component_length = componentList.component.length;
							nodeChanges[idx].failed_dependency_cnt = componentList.failed_dependency;
						}
					}
					
					var componentCount = 0;
					for (var idx = 0; idx < nodeChanges.length; idx++) {
						componentCount += nodeChanges[idx].component_length;
					}
					
					if ( value == true ) {
					if (componentCount > 0) {
						$(DEPLOY).attr("disabled", true);
						$(ANALYSIS).attr("disabled", false);
					}
					else {
						$(DEPLOY).attr("disabled", false);
						$(ANALYSIS).attr("disabled", true);
					}
					}
					
					var name  = '#hpsum-group-node-cname-' + id;
					if(componentList.failed_dependency != 0){
						$(name).html('&nbsp&nbsp<p><img src="/img/hp-piano/status-error-small-select.png">&nbsp&nbsp' + nodeName + '<br/>' +
						'&nbsp&nbsp' + localizer.getString("hpsum.node.compFailedDep", [componentList.component.length]));
					}
					else{
						if(componentList.component.length == 0){
							$(name).html('&nbsp&nbsp<p><img src="/img/hp-piano/status-warning-small-select.png">&nbsp&nbsp' + nodeName + '<br/>' +
							'&nbsp&nbsp' + localizer.getString("hpsum.node.compSelectZero", [componentList.component.length]));
						}
						else{
							$(name).html('&nbsp&nbsp<p><img src="/img/hp-piano/status-ok-small-select.png">&nbsp&nbsp' + nodeName + '<br/>' +
							'&nbsp&nbsp' + localizer.getString("hpsum.node.compSelect", [componentList.component.length]));
						}	
					}
				}
				

				function onAnalysis() {
				
					if(!validateRebootDelay())
						return;
						
					if(!validate())
					{
						$(ANALYSIS).attr("disabled", true);
						$(INSTALL_ERROR).text(localizer.getString("hpsum.node.forceOptionSoftwareError"));
						$(INSTALL_ERROR).show();
						return false;
					}
					    
					showAnalysisWaitDialog();
					
					setoptiondetails();
					
					setscheduleoptions(groupItem);
					if (setAttributesOnGroup) {
						presenter.setAttributes(groupItem, optiondetails, {
							success : onSetattributeSuccess,
							error : onSetattributeError
						});
					}
					else
						performAnalysis();
				}
				
				function performAnalysis() {
					var analysisStartedNodes = 0,
					    cContentId,
					    instalables,
					    componentsList;
						
					for (var idx = 0; idx < nodeChanges.length; idx++) {
						if (nodeChanges[idx].selectionChanged == true ) {
							cContentId = '#hpsum-group-node-ccontent-' + nodeChanges[idx].node_id;
							instalables = $(cContentId).data('plugin_hpsumInstallables');
							componentsList = instalables.getComponents();

							nodePresenter.analysis({
								node_id : nodeChanges[idx].node_id
							}, 
							componentsList, {
								node_id : nodeChanges[idx].node_id,
								success : function(data) {
								},
								error : function(errorInfo) {
								}
							});
							analysisStartedNodes++;
						}
					}
					
					var timer = setInterval(function() {
						presenter.getGroupStatus({group_id: groupItem.group_id}, {
							success : function(data) {
								if (data.hapi.hcode == 0) {
									if (data.hapi.group_status.match(/Ready to start deploy/)) {
										clearInterval(timer);			
										var enableDeployCnt = 0;
										var componentCount = 0;
										for (var idx = 0; idx < nodeChanges.length; idx++) {
											componentCount += nodeChanges[idx].component_length;
											nodeChanges[idx].selectionChanged = false;
											if (nodeChanges[idx].failed_dependency_cnt > 0) {
												enableDeployCnt++;	
											}
											$('#hpsum-group-node-ccontent-' + nodeChanges[idx].node_id).hpsumInstallables('recalculate'); 
										}
										
										if (0 == enableDeployCnt) {
											if (0 == componentCount)
											{
												$(DEPLOY).attr("disabled", true);
												$(ANALYSIS).attr("disabled", true);
											}
											else
											{
												$(DEPLOY).attr("disabled", false);
												$(ANALYSIS).attr("disabled", true);
											}
										}
										else {
											
											$(DEPLOY).attr("disabled", true);
											$(ANALYSIS).attr("disabled", true);
										}
										
										closeAnalysisWaitDialog();
									}
								}
							},
							error : function(data) {
								clearInterval(timer);
								closeAnalysisWaitDialog();
							}
						});
					}, 3000); 

				}

				function showAnalysisWaitDialog() {
						analysisWaitDialog = $(SPLASH_DIALOG);
						analysisWaitDialog.dialog({
							modal : true,
							dialogClass : 'hp-simple-dialog',
							position : "center",
							draggable : false,
							resizable : false,
							width : 280,
							height : 180
						});
					$(SPLASH_SPINNER).show();
					analysisWaitDialog.dialog('open');
				}

				function closeAnalysisWaitDialog() {
					$(SPLASH_SPINNER).hide();
					analysisWaitDialog.dialog('destroy');
				}		
				
				
				function reset() {
					populateOptions();
					nodeChanges = [];
					populateDeployData();
					$(SCHEDULE_DATE).val("");
					$(SCHEDULE_TIME).val("");
					$(DELAYSEC).attr("disabled", true);
					$(MESSAGE).attr("disabled", true);
					$(DELAYSEC).removeClass("hp-error");
					$(DELAYSECERR).hide();
				}
				
				function validateTime() {
					var time_val = $(SCHEDULE_TIME).val();
					var time_parse = time_val.split(':');
					var time_pattern = /^([0-9]|0[0-9]|1[0-9]|2[0-3]):[0-5][0-9]$/;
					if(!time_val.match(time_pattern)) {
						$(SCHEDULE_TIME_LABEL).addClass("hp-error");
						$(SCHEDULE_TIME_LABEL).show();
						$(ANALYSIS).attr("disabled", true);
					}
					else
					{
						var time_hrs = time_parse[0];
						var time_mins = time_parse[1];
						if(time_hrs >= 12)
						{
							if(time_hrs == 12)
								schedule_time = time_hrs + ':' + time_mins + ' ' +'PM';
							else
							{
								var time_hrs_old = time_hrs - 12 ;
								if((time_hrs_old) <= 9)
								schedule_time = '0' + time_hrs_old + ':' + time_mins + ' ' +'PM';
								else 
								schedule_time = time_hrs_old + ':' + time_mins + ' ' +'PM';
							}
						}
						else if (time_hrs == 0)
						{
							schedule_time = (parseInt(time_hrs) + 12) + ':' + time_mins + ' ' +'AM';
						}
						else if (time_hrs < 12)
						{
							schedule_time = time_hrs + ':' + time_mins + ' ' +'AM';
						}
						$(ANALYSIS).removeAttr('disabled');
						$(DEPLOY).attr('disabled','disabled');
					}
				}
				
				function validateRebootDelay() {
					var rebootopt = $('#hpsum-deploy-reboot-option option:selected').val();
					var delaySec = $(DELAYSEC).val();
					var valid = true;
					
					if (rebootopt != "Never") {
						if((isNaN(delaySec) && !isFinite(delaySec)) || 
						  (delaySec < 60 || delaySec > 3600)) {
							$(ANALYSIS).attr("disabled", true);
							$(DELAYSEC).addClass("hp-error");
							$(DELAYSECERR).text(localizer.getString("hpsum.node.rebootDelaySecondsErrMsg"));
							$(DELAYSECERR).show();
							valid = false;
						}
						else {
							$(DELAYSEC).val(parseInt(delaySec));
							$(ANALYSIS).attr("disabled", false);
							$(DELAYSEC).removeClass("hp-error");
							$(DELAYSECERR).hide();
						}
					}
					return valid;
				}
				
				function convertDateTime(date_time)
				{
					date_value = '';
					time_value = '';
					date_time_new = '';
					if(date_time !== "")
					{
						var date_time_split = date_time.split(' ');
						var time_hrs_mins = date_time_split[1].split(':');
						var time_hrs = time_hrs_mins[0];
						date_value = date_time_split[0];
						time_value = '';
						date_time_new = '';
						if((date_time_split[2] == 'PM') && (parseInt(time_hrs) < 12))
						{
							time_hrs = parseInt(time_hrs) + 12;
						}
						else if(date_time_split[2] == 'AM')
						{
							if (parseInt(time_hrs) < 10 && parseInt(time_hrs) < 12)
							{
								time_hrs = '0' + parseInt(time_hrs);
							}
							else if (parseInt(time_hrs) == 12)
							{
								time_hrs = parseInt(time_hrs) - 12;
								time_hrs = '0' + parseInt(time_hrs);
							}
						}
						time_value = time_hrs + ':' + time_hrs_mins[1];
						date_time_new = date_value + ' ' + time_value;
					}
				}
				function setscheduleoptions(groupItem) {
				
					var scheduled = "no";
					var date = "";
					var time = "";
					
					if($(SCHEDULETOGGLE).attr('checked') === "checked")
						scheduled = 'yes';
					else
						scheduled = 'no';
					
					if(scheduled_getdata_date_time == ""){
						scheduled_getdata_date_time = " ";
						schedaction = 'create';
						}
					else
						schedaction = 'update';
					
					if(scheduled === "yes"){
						date = $(SCHEDULE_DATE).val();
						validateTime();
						time = schedule_time;
					}
					
					var schedule_information = {date:date, time:time};
					var schedule_date_time = date + ' ' + time;
					if(scheduled !== scheduled_getdata || scheduled_getdata_date_time !== schedule_date_time)
						presenter.ScheduleNodes(groupItem, schedaction, scheduled, schedule_information, {
							success : function(data) {
								onScheduleNodesSuccess(data); 
							},
							error : function(errorInfo) {
									onScheduleNodesError(errorInfo);
								}
						});
				}
				
				function loadScheduleoptions(groupItem){
					var scheduled_time = '',
						scheduled_date = '',
						timezone = groupItem.group_schedule_timezone,
						current_date_time = '',
						nodeScheduled = false;
						

					scheduled_getdata_date_time = groupItem.group_schedule_date_time;
					scheduled_getdata = groupItem.group_scheduled;
					if(scheduled_getdata === "false")
					{
						scheduled_getdata = "no";
						$(DEPLOY).val(localizer.getString('hpsum.node.deploy'));
						if($(SCHEDULETOGGLE).attr('checked') === "checked"){
							$(SCHEDULETOGGLE).click();	
							$(SCHEDULETOGGLE).removeAttr("checked");
						}
					}
					else if(scheduled_getdata === "true")
					{
						scheduled_getdata = "yes";
						$(DEPLOY).val(localizer.getString('hpsum.node.scheduledeploy'));
						if($(SCHEDULETOGGLE).attr('checked') === undefined){
							$(SCHEDULETOGGLE).click();	
							$(SCHEDULETOGGLE).attr("checked","checked");
						}
					}
					if(scheduled_getdata_date_time !== "")
					{
						convertDateTime(scheduled_getdata_date_time);
						scheduled_date = date_value;
						scheduled_time = time_value;
					}
					
					$(SCHEDULE_DATE).val(scheduled_date);
					$(SCHEDULE_TIME).val(scheduled_time);
					
					convertDateTime(groupItem.group_local_date_time);
					current_date_time = date_time_new;
					$(CURRENT_DATETIME).html(current_date_time);
					$(TIME_ZONE).html(timezone);
					
					var tableContents = "<table><thead><tr><th>Node IP</th><th>Schedule DateTime</th>";//<th>RunNow</th><th>RetainSchedule</th>";
					for(var idx = 0; idx < allNodesDetials.length; idx++){
						if(allNodesDetials[idx].is_schedule_running === "true")
						{
							nodeScheduled = true;
							convertDateTime(allNodesDetials[idx].schedule_date_time);
							tableContents += "<tr><td>" + allNodesDetials[idx].name + "</td><td>" + date_time_new + "</td>";
							//tableContents += "<td><input type = checkbox id=runnow></td><td><input type=checkbox id=retainschedule></td></tr>";
						}
					}
					tableContents += "</table>";
					if(!groupItem.group_schedule_running && nodeScheduled)
					{						
						warningmsg = localizer.getString('hpsum.group.scheduleDeployWarning');
						$('#hpsum-group-warning-label').html(warningmsg);
						$(SCHEDULE_WARNING).show();
						$(SCHEDULE_LIST).show();
						$(SCHEDULE_LIST).html(tableContents);
					}
					else
					{
						$(SCHEDULE_WARNING).hide();
						$(SCHEDULE_LIST).html('');
						$(SCHEDULE_LIST).hide();
					}
					
				}

				function onScheduleNodesError(errorMessage)
				{
					notifications.show(errorMessage, 'error');                          
					$(ANALYSIS).attr("disabled", false);
					$(DEPLOY).attr("disabled", true);	
					$(CANCEL).trigger('click');	
				}

				function onScheduleNodesSuccess(data)
				{
					var message;	
					$(DEPLOY).val(localizer.getString('hpsum.node.scheduledeploy'));
					if(schedaction === "create")
						message = "Schedule for " + groupItem.group_name + " group created successfully";
					if(schedaction === "update"){
						if($(SCHEDULETOGGLE).attr('checked') === "checked")
							$(DEPLOY).val(localizer.getString('hpsum.node.scheduledeploy'));
						else
							$(DEPLOY).val(localizer.getString('hpsum.node.deploy'));
						message = "Schedule for " + groupItem.group_name + " group updated successfully";  
					}
					notifications.show(message, 'ok');  
					$(SCHEDULE_WARNING).hide();
					$(SCHEDULE_LIST).html('');
					$(SCHEDULE_LIST).hide();
				}	
				
				function optionValueChanged()
				{
					var optionSelected = false, atleastOneOptionSelected = false;
					optiondetails.hapi.installation_option.force = false;
					$(INSTALL_ERROR).hide();
					var type = $(INSTALLATIONOPTION).val();
					if ( type != 'None')
					{
								if ( type=="Downgrade") 
									optiondetails.hapi.installation_option.downgrade = true;
								  if ( type=="Rewrite") 
									optiondetails.hapi.installation_option.rewrite = true;
								  if ( type == "Both")
								  {
									optiondetails.hapi.installation_option.downgrade = true;
									optiondetails.hapi.installation_option.rewrite = true;
								  }
							
					optiondetails.hapi.installation_option.software =  $(SOFTWARECHKBOXCOMP).is(':checked');	
				    optiondetails.hapi.installation_option.firmware =  $(FIRMWARECHKBOXCOMP).is(':checked');	
					atleastOneOptionSelected = true;
					if ( optiondetails.hapi.installation_option.software ^ optiondetails.hapi.installation_option.firmware )
					optiondetails.hapi.installation_option.force = true;
					}
					
					
					if (!atleastOneOptionSelected) {
						optiondetails.hapi.installation_option = {};
					} else {
						setAttributesOnGroup = true;						
						var componentCount = 0;
						for (var idx = 0; idx < nodeChanges.length; idx++) {
							componentCount += nodeChanges[idx].component_length;
						}
						
						if (componentCount > 0) {
							$(DEPLOY).attr("disabled", 'disabled');
							$(ANALYSIS).removeAttr('disabled');
						}
						else 
							$(ANALYSIS).attr("disabled", 'disabled');
						
						
					} 
					atleastOneOptionSelected = false;
				}
				
				function toggleSchedule(cb)
				{
					if(cb.target.checked){
						$(DATETIMESECTION).show();
						warningmsg = localizer.getString('hpsum.group.scheduleToggleWarning');
					}
					else
						$(DATETIMESECTION).hide();
					$('#hpsum-group-warning-label').html(warningmsg);
					$(DEPLOY).val(localizer.getString('hpsum.node.deploy'));
					$(DEPLOY).attr('disabled','disabled');
					
					var componentCount = 0;
					for (var idx = 0; idx < nodeChanges.length; idx++) {
						componentCount += nodeChanges[idx].component_length;
					}
						
					if (componentCount > 0) {
						$(ANALYSIS).removeAttr('disabled');
					}
					else 
						$(ANALYSIS).attr("disabled", 'disabled');
				}
				/**
				 * @public
				 * Initialize Group Deploy View
				 */
				this.init = function() {

					$(DEPLOY).live('click', function(ev) {
						onDeploy.call(this);
						ev.preventDefault();
					});
					
					$(CANCEL).live('click', function() {
						$('.hpsumInstallables').hpsumInstallables('destroy');
						presenter.off("itemChange", onItemChange);
						router.go(urlFragment.replaceView(router.location(), 'show'));
					});
					
					$(ANALYSIS).live('click', function(ev) {
						onAnalysis.call(this);
						ev.preventDefault();
					});
					
					$('.require-analysis').on('change', function(){
                        $(ANALYSIS).attr('disabled',false);
                        $(DEPLOY).attr('disabled',true);
					});
					
					//By Default reboot-options value is Never so disable the Reboot delay and Reboot message.
					$(REBOOT_DISABLE).find('input,textarea,select,button').prop("disabled", true);
					
					$(REBOOTOPTION).change(function() {
						var type = $('#hpsum-deploy-reboot-option option:selected').val();
						if (type == "Never") {
						$(REBOOT_DISABLE).find('input,textarea,select,button').prop("disabled", true);
						$(DELAYSEC).val('');
						$(DELAYSEC).removeClass("hp-error");
						$(DELAYSECERR).hide();
						}
						else
						{
						$(REBOOT_DISABLE).find('input,textarea,select,button').prop("disabled", false);
						}
					});
					
					$(DELAYSEC).unbind('keyup').bind('keyup',function(){
					//	$(ANALYSIS).attr("disabled", false);
					//	$(DEPLOY).attr("disabled", true);
						$(DELAYSECERR).hide();
						$(DELAYSEC).removeClass('hp-error');
					}); 
					
					$(DELAYSEC).bind('change', function(){
					//	$(ANALYSIS).attr("disabled", false);
					//	$(DEPLOY).attr("disabled", true);
						$(DELAYSECERR).hide();
						$(DELAYSEC).removeClass('hp-error');
					}); 
					
					$(PANELS).hpStackedPanels({
						panelSelector : PANEL_SELECTOR
					});

					$(".hp-collapsible").hpCollapsible();

					$(DEPLOY).attr("disabled", false);

					$(RESET).live('click', function() {
						reset.call();
					});
					
					$('#hpsum-downgrade-rewrite-text').html(localizer.getString("hpsum.node.installationMessage"));
					$('#hpsum-downgrade-rewrite-text').removeClass('hp-collapsed');
					$(INSTALL_ERROR).hide();
					$("#hpsum-installation-option").change(function() {
						var type = $(INSTALLATIONOPTION).val();
						if (type == "None")
						{
							$('#hp-force-downgrade-rewrite').hide();
							$(FIRMWARECHKBOXCOMP).attr('checked', false);							
							$(SOFTWARECHKBOXCOMP).attr('checked', false);
						}
						else
							$('#hp-force-downgrade-rewrite').show();
						$(INSTALL_ERROR).hide();
						//optionValueChanged();
						
					});
				$("#hpsum-reboot-options-collapsible").css("margin-top","-20px");
				$(INSTALLATIONOPTION).selectBox({autoWidth: false});
				$(INSTALLATIONOPTION).val('None');
				$(INSTALLATIONOPTION).selectBox('reset');
				$('#hp-force-downgrade-rewrite').hide();
					
					router.watch('Group Deploy section', ROUTE_PREFIX + '.*', {
						parent : ROUTE_PREFIX,
						change : changeLocation
					});
					$(DATETIMESECTION).hide(); 
					
					$(FIRMWARECHKBOXCOMP).bind('change', function(){
						$(INSTALL_ERROR).hide();
					});
					$(SOFTWARECHKBOXCOMP).bind('change', function(){
						$(INSTALL_ERROR).hide();
					});
					
					$(SCHEDULETOGGLE).hpToggle({checked: 'On', unchecked: 'Off'});
					$(SCHEDULETOGGLE).bind('change',toggleSchedule);
					$(SCHEDULE_DATE).datepicker({ dateFormat: 'yy-mm-dd'});
					$(SCHEDULE_TIME).bind('change', validateTime);
					$(SCHEDULE_TIME).bind('keyup', function () {
						$(SCHEDULE_TIME_LABEL).removeClass("hp-error");
						$(SCHEDULE_TIME_LABEL).hide();
						$(ANALYSIS).removeAttr('disabled');
					});
					$(SCHEDULE_TIME_LABEL).removeClass("hp-error");
					$(SCHEDULE_TIME_LABEL).hide();
					$(SCHEDULE_DATE).bind('change', function(){
						$(ANALYSIS).removeAttr('disabled');
						$(DEPLOY).attr('disabled','disabled');
					});
					$("#hpsum-schedule-collapsible").removeClass('hp-collapsed');
					this.resume();
				};

				/**
				 * @public
				 * Resume Group Deploy View
				 */
				this.resume = function() {
					$(THROBBER).hide();
					presenter.on("itemChange", onItemChange);
					$(PANELS).hpStackedPanels('resume');
					reset();
					$('#hpsum-group-deploy').hpCollapsible('expand');
					$(SCHEDULE_TIME_LABEL).removeClass("hp-error");
					$(SCHEDULE_TIME_LABEL).hide();
				};

				/**
				 * @public
				 * Pause Group Deploy View
				 */
				this.pause = function() {
					presenter.off("itemChange", onItemChange);
					$(PANELS).hpStackedPanels('pause');
				};
			}

			return GroupDeployView;
		}());

	return new GroupDeployView();
});
